<?php
/**
 * Plugin Name: Wolf Sidebars
 * Plugin URI:  http://wpwolf.com/wolf-sidebars
 * Description: A Sidebars / Widget Areas Manager
 * Version: 1.0.1
 * Author: WpWolf
 * Author URI: http://wpwolf.com/about/
 * Requires at least: 3.5
 * Tested up to: 3.8.1
 *
 * Text Domain: wolf
 * Domain Path: /lang/
 *
 * @package WolfSidebars
 * @author WpWolf
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Wolf_Sidebars' ) ) {
/**
 * Main Wolf_Sidebars Class
 *
 * Contains the main functions for Wolf_Sidebars
 *
 * @class Wolf_Sidebars
 * @version 1.0.1
 * @since 1.0.0
 * @package WolfSidebars
 * @author WpWolf
 */
class Wolf_Sidebars {

	/**
	 * @var string
	 */
	private $update_url = 'http://plugins.wpwolf.com/update';


	/**
	 * Wolf_Sidebars Constructor.
	 *
	 * @access public
	 * @return void
	 */
	public function __construct() {

		define( 'WOLF_WIDGET_AREA', true );
		define( 'WOLF_SIDEBARS_URL', plugins_url() . '/' . basename( dirname( __FILE__) ) );
		define( 'WOLF_SIDEBARS_DIR', dirname( __FILE__ ) );
		
		// Register hooks that are fired when the plugin is activated, deactivated, and uninstalled, respectively.
		register_activation_hook( __FILE__, array( $this, 'activate' ) );
		
		// Load plugin text domain
		add_action( 'init', array( $this, 'plugin_textdomain' ) );

		// Register created Sidebars
		add_action( 'after_setup_theme', array( &$this, 'register_sidebars' ) );

		// Print sidebar styles
		add_action( 'wp_print_styles', array( &$this, 'print_styles' ) );

		// Add meta box
		add_action( 'add_meta_boxes', array( &$this, 'add_meta_box' ) );
		add_action( 'save_post', array( &$this, 'save_metabox' ) );

		// Add Widget Area Shortcode
		add_shortcode( 'wolf_widgetarea', array( &$this, 'widgetarea_shortcode' ) );

		// Tiny MCE shortcode generator button
		add_action( 'admin_init', array( &$this, 'mce_init' ) );

		// Add menu
		add_action( 'admin_menu', array( &$this, 'add_menu' ) );

		// admin styles & scripts
		add_action( 'admin_print_styles', array( &$this, 'admin_styles' ) );
		add_action( 'admin_enqueue_scripts', array( &$this, 'admin_script' ) );

		// plugin update
		add_action( 'admin_init', array( &$this, 'plugin_update' ) );

	}


	/**
	 * Create Sidebar Table on plugin activation
	 */
	public function activate( $network_wide ) {
		
		$this->create_table();

	} // end activate


	/**
	 * Loads the plugin text domain for translation
	 */
	public function plugin_textdomain() {

		$domain = 'wolf';
		$locale = apply_filters( 'wolf', get_locale(), $domain );
		load_textdomain( $domain, WP_LANG_DIR.'/'.$domain.'/'.$domain.'-'.$locale.'.mo' );
		load_plugin_textdomain( $domain, FALSE, dirname( plugin_basename( __FILE__ ) ) . '/lang/' );

	}


	/**
	 * Create Sidebar Table
	 */
	public function create_table() {
		global $wpdb;
		$table ="CREATE TABLE IF NOT EXISTS `{$wpdb->prefix}wolf_sidebars` (
		  `id` int(11) NOT NULL AUTO_INCREMENT,
		  `wp_id` varchar(255) NULL,
		  `name` varchar(255) NULL,
		  `desc` text NULL,
		  `type` text NULL,
		  `cols` varchar(255) NULL,
		  `position` int(11) NOT NULL DEFAULT 0,
		  PRIMARY KEY (`id`)
		);";
		$wpdb->query($table);
	}


	/**
	 * Enqueue  styles
	 */
	public function print_styles() {

		wp_enqueue_style( 'wolf-sidebars', WOLF_SIDEBARS_URL. '/css/sidebars.css', array(), '1.0' );

	}


	/**
	 * Enqueue admin styles
	 */
	public function admin_styles() {

		if ( isset( $_GET['page'] ) ){
			
			if ( $_GET['page'] == 'wolf-sidebars.php' )
				wp_enqueue_style( 'wolf-sidebars-admin', WOLF_SIDEBARS_URL.'/css/sidebars-admin.css', array(), '1.0', 'all' );

		}

	}


	/**
	 * Enqueue admin scripts
	 */
	public function admin_script() {
		
		if ( isset( $_GET['page'] ) ){
		
			if ( $_GET['page'] == 'wolf-sidebars.php' ){
				wp_enqueue_script( 'jquery-ui-sortable' );
			}
			
		}
	}


	/**
	 * Add menu
	 */
	public function add_menu() {

		add_menu_page( __( 'Sidebars & Widget Areas', 'wolf'), __( 'Sidebars & Widget Areas', 'wolf'), 'activate_plugins', basename( __FILE__ ), array( &$this, 'sidebar_panel' ) , 'dashicons-welcome-widgets-menus' );

	}


	/**
	 * Sidebar admin page
	 */
	public function sidebar_panel() {

		require_once( 'includes/wolf-sidebars-panel.php' );

	}


	public function get_all_sidebars() {
		global $wpdb;
		$wolf_sidebars_table = $wpdb->prefix.'wolf_sidebars';
		$sidebars = $wpdb->get_results( "SELECT * FROM $wolf_sidebars_table ORDER BY position" );
		return $sidebars;
	}


	public function get_sidebars() {
		global $wpdb;
		$wolf_sidebars_table = $wpdb->prefix.'wolf_sidebars';
		$sidebars = $wpdb->get_results( "SELECT * FROM $wolf_sidebars_table WHERE type = 'sidebar' ORDER BY position" );
		return $sidebars;
	}


	public function get_widgetareas() {
		global $wpdb;
		$wolf_sidebars_table = $wpdb->prefix.'wolf_sidebars';
		$sidebars = $wpdb->get_results( "SELECT * FROM $wolf_sidebars_table WHERE type = 'widgetarea' ORDER BY position" );
		return $sidebars;
	}


	/**
	 *  Register created sidebars
	 */
	public function register_sidebars() {

		$sidebars = $this->get_all_sidebars();
		
		if ( $sidebars ){

			foreach($sidebars as $sidebar){

				if ( $sidebar->type == 'sidebar' ){

					$args = array(
						'name'      => $sidebar->name,
						'id'            => $sidebar->wp_id,
						'description' => $sidebar->desc,
						'before_widget' => '<aside id="%1$s" class="widget %2$s"><div class="widget-content">',
						'after_widget'  => '</div></aside>',
						'before_title'  => '<h3 class="widget-title">',
						'after_title'   => '</h3>',
					);

				}elseif ( $sidebar->type == 'widgetarea' ){
					
					$columns = array(
						6 => 2,
						4 => 3,
						3 => 4,
						12 => 1
					);
					
					$args = array(
						'name'      => $sidebar->name . ' - ' . sprintf( __( 'widget area (%d columns)', 'wolf' ), $columns[$sidebar->cols]  ) ,
						'id'            => $sidebar->wp_id,
						'description' => $sidebar->desc,
						'before_widget' => '<aside id="%1$s" class="widget wolf_widget_col_' . $sidebar->cols . ' %2$s"><div class="widget-content">',
						'after_widget'  => '</div></aside>',
						'before_title'  => '<h3 class="widget-title">',
						'after_title'   => '</h3>',
					);
				}

				register_sidebar($args);
			}
		}
	}


	/**
	 * Add metabox
	 */
	public function add_meta_box() {
		global $post;
		$current_post_type  = '';
		if ( $post )
			$current_post_type = get_post_type( $post->ID );

		if ( $current_post_type == 'page' ) {
			add_meta_box(
				'wolf_sidebar_meta_box', // $id
				__( 'Sidebar', 'wold' ), // $title 
				array( &$this,'show_sidebars_list' ), // $callback
				'page', // $page
				'side', // $context
				'default'); // $priority
		}
	}


	/**
	 *  Add select input in the post editor to choose which sidebar to use on the page
	 */
	public function show_sidebars_list() {
		
		global $wp_registered_sidebars, $post, $wpdb;
		$meta = get_post_meta( get_the_ID() , '_wolf_sidebar', true );
		$sidebars = $wp_registered_sidebars;

		$wolf_sidebars_table = $wpdb->prefix.'wolf_sidebars';
		$sidebars = $this->get_sidebars();

		?>
		<select name="wolf_sidebar" id="wolf_sidebar">
			<option value="main" <?php if( $meta == 'main' ){ echo 'selected="selected"';} ?>><?php _e( 'Main Sidebar', 'wolf' ); ?></option>
			<?php foreach( $sidebars as $sidebar ) : ?>
			<option value="<?php echo $sidebar->wp_id; ?>" <?php if( $meta == $sidebar->wp_id ){ echo 'selected="selected"';} ?>><?php echo $sidebar->name; ?></option>
			<?php endforeach; ?>
		</select>
		<?php
	}


	/**
	 * Save metabox
	 */
	public function save_metabox( $post_id ) {

		// verify nonce
		if ( (isset($_POST['sidebar_meta_box_nonce'])) && (!wp_verify_nonce($_POST['sidebar_meta_box_nonce'], basename(__FILE__)))) 
			return $post_id;

		// check autosave
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
			return $post_id;
		
		// check permissions
		if(isset($_POST['post_type'])){
			if ('page' == $_POST['post_type']) {
				if (!current_user_can('edit_page', $post_id))
					return $post_id;
				} elseif (!current_user_can('edit_post', $post_id)) {
					return $post_id;
			}
		}

		if((isset($_POST['post_type'])) && ($_POST['post_type'] == 'page')){
			if(isset($_POST['wolf_sidebar'])){
				
				$old = get_post_meta( $post_id, '_wolf_sidebar', true );
				$new = $_POST['wolf_sidebar'];
				
				if ($new && $new != $old ) {
					
					update_post_meta($post_id, '_wolf_sidebar', $new);
				
				} elseif ('' == $new && $old) {
					
					delete_post_meta($post_id, '_wolf_sidebar', $old);
				}
			}
		}
	}



	/**
	 * Widget Area Shortcode
	 */
	public function widgetarea_shortcode( $atts ) {
		
		extract( shortcode_atts( array(
		        'id' => '',
		     ), $atts ) );
		
		ob_start();
		dynamic_sidebar( $id );
		$widgetarea = ob_get_contents();
		ob_end_clean();
		return '<div id="wolf-widget-area-' . $id . '" class="wolf-widget-area">'.$widgetarea.'</div>';
	}


	/**
	 *  Display Sidebar
	 */
	public function do_sidebar() {

		$sidebar = 'main';
		
		if ( have_posts() ) {
			
			while ( have_posts() ) : the_post();

				$post_id = get_the_ID();
		
				if ( get_post_meta( $post_id, '_wolf_sidebar', true) ) {

					$sidebar = get_post_meta( $post_id, '_wolf_sidebar', true); 

				}
			
			endwhile;
		}

		return dynamic_sidebar( $sidebar );
	}


	/**
	 * Registers TinyMCE rich editor buttons
	 */
	public function mce_init() {
		
		if ( ! current_user_can( 'edit_posts' ) && ! current_user_can( 'edit_pages' ) )
			return;
	
		if ( get_user_option( 'rich_editing' ) == 'true' )
		{
			add_filter( 'mce_external_plugins', array( &$this, 'add_rich_plugins' ) );
			add_filter( 'mce_buttons', array( &$this, 'register_rich_buttons' ) );
		}
	}

	
	/**
	 * Defines TinyMCE rich editor js plugin
	*/
	public function add_rich_plugins( $plugin_array ) {
		$plugin_array['WolfWidgetareas'] = WOLF_SIDEBARS_URL . '/tinymce/plugin.js';
		return $plugin_array;
	}

	
	/**
	 * Adds TinyMCE rich editor buttons
	 */
	public function register_rich_buttons( $buttons ) {
		array_push( $buttons, 'wolf_widgetarea_button' );
		return $buttons;
	}


	/**
	 * Localize TinyMCE plugin Script
	 */
	public function admin_scripts() {
		
		if ( ! wp_script_is('jquery') )
			wp_enqueue_script( 'jquery' );

		wp_localize_script( 'jquery', 'WolfWidgetareas', array( 'plugin_folder' => WOLF_PLUGIN_URL .'/tinymce/' ) );
	}


	/**
	 * Plugin update
	 */
	public function plugin_update() {
		
		$plugin_data = get_plugin_data( __FILE__ );

		$current_version = $plugin_data['Version'];
		$plugin_slug = plugin_basename( dirname( __FILE__ ) );
		$plugin_path = plugin_basename( __FILE__ );
		$remote_path = $this->update_url . '/' . $plugin_slug;
		
		if ( ! class_exists( 'Wolf_WP_Update' ) )
			include_once('classes/class-wp-update.php');
		
		new Wolf_WP_Update( $current_version, $remote_path, $plugin_path );
	}


} // End Class

global $wolf_sidebars;
$wolf_sidebars = new Wolf_Sidebars;

if ( ! function_exists( 'wolf_sidebar' ) ) :
/**
 *  Displays Sidebar
 */
function wolf_sidebar() {
	global $wolf_sidebars;
	$wolf_sidebars->do_sidebar();
}
endif;

} // end class check